/// This is part of the MTP Implementation
/// (C) Daniel Kirstenpfad 2004-2005
/// 
/// 08.01.2005	-	initial Release																					-	Daniel Kirstenpfad
using System;

namespace MTP
{
	/// <summary>
	/// Implements the Situation-depending Status Handling
	/// </summary>
	public class DeviceStatus
	{
		private FunctionalModes internalcurrentDeviceFunctionalMode;
		private static bool internalDeviceBusy;

		/// <summary>
		/// Property to set and get the current DeviceFunctionalMode
		/// </summary>
		public FunctionalModes currentDeviceFunctionalMode
		{
			get
			{
				return internalcurrentDeviceFunctionalMode;
			}
			set
			{
				internalcurrentDeviceFunctionalMode = value;
			}
		}

		/// <summary>
		/// what Operations are available at current FunctionalMode
		/// </summary>
		/// <returns>OperationCodes in an array</returns>
		public OperationCodes[] currentDeviceOperationCodes()
		{
			switch(currentDeviceFunctionalMode)
			{         
				case FunctionalModes.StandardMode: return DeviceSpecificInformations.StandardmodeOperations;
				case FunctionalModes.SleepState: return DeviceSpecificInformations.SleepStateOperations;
				case FunctionalModes.ResponsivePlayback: return DeviceSpecificInformations.ResponsivePlaybackOperations;
				case FunctionalModes.NonResponsivePlayback: return DeviceSpecificInformations.NonResponsivePlaybackOperations;	
				default: return new OperationCodes[1] {OperationCodes.Undefined};
			}
		}

		/// <summary>
		/// what Events are available at current FunctionalMode
		/// </summary>
		/// <returns>available EventCodes in an array</returns>
		public EventCodes[] currentDeviceEventCodes()
		{
			switch(currentDeviceFunctionalMode)
			{         
				case FunctionalModes.StandardMode: return DeviceSpecificInformations.StandardmodeEvents;
				case FunctionalModes.SleepState: return DeviceSpecificInformations.SleepstateEvents;
				case FunctionalModes.ResponsivePlayback: return DeviceSpecificInformations.ResponsivePlaybackEvents;
				case FunctionalModes.NonResponsivePlayback: return DeviceSpecificInformations.NonResponsivePlaybackEvents;	
				default: return new EventCodes[1] {EventCodes.Undefined};
			}
		}

		/// <summary>
		/// true if the device is busy
		/// </summary>
		public static bool bDeviceBusy
		{
			get
			{
				return internalDeviceBusy;
			}
			set
			{
				internalDeviceBusy = value;
			}
		}
	}
}