using System;
using System.Collections;

namespace MTP
{
	#region Single Session Class
	/// <summary>
	/// Implements a single Session with all Handling and Data
	/// </summary>
	public class Session
	{
		private Int32 iSessionID;

		#region private Helper Methods
		/// <summary>
		/// generates a new SessionID
		/// </summary>
		/// <returns>new Session ID</returns>
		private Int32 GenerateNewSessionID()
		{
			// TODO: check if the random number was generated once before - a SessionID should be unique

			System.Threading.Thread.Sleep(1);	

			System.Random RandomNumberGenerator = new Random();	// Auto-Seeding

			return RandomNumberGenerator.Next(Int32.MinValue,Int32.MaxValue);
		}
		#endregion

		/// <summary>
		/// Session Constructor and Initialization
		/// </summary>
		public Session()
		{
			// generate SessionID
			iSessionID = GenerateNewSessionID();
		}

		/// <summary>
		/// Method to retrieve the SessionID of this Session
		/// </summary>
		public int SessionID
		{
			get
			{
				return iSessionID;
			}
		}
	}
	#endregion

	#region SessionHandling Class
	/// <summary>
	/// Implements all session-related handling
	/// </summary>
	public class SessionHandling
	{
		private static System.Collections.ArrayList SessionCollection = new System.Collections.ArrayList();

		/// <summary>
		/// creates and initializes a new Session
		/// </summary>
		/// <returns>Session Object</returns>
		public Session CreateSession()
		{
			Session newSession = new Session();

			// add Session to the SessionCollection
			SessionCollection.Add(newSession);

			return newSession;
		}

		/// <summary>
		/// deletes a Session, identified by its SessionID
		/// </summary>
		/// <param name="lSessionID">SessionID of the to-delete Session</param>
		/// <returns>true if Deletion was successful, false if unsuccessful</returns>
		public bool DeleteSession(Int32 lSessionID)
		{
			// find Session with given SessionID
			for (int i=0;i<=SessionCollection.Count;i++)
			{
				Session tSession = (Session)SessionCollection[i];
				if (tSession.SessionID == lSessionID)
				{
					// remove the Session Object from the Collection and let the Garbage Collector do the dirty work
					SessionCollection.Remove(tSession);
					return true;
				}
			}
			return false;
		}

		/// <summary>
		/// Checks if a given Session does exist (identified via SessionID)
		/// </summary>
		/// <param name="lSessionID">SessionID of wanted Session</param>
		/// <returns>true if Session with given SessionID exists, false if it does not exist</returns>
		public bool lookupSession(Int32 lSessionID)
		{
			// find Session with given SessionID
			for (int i=0;i<=SessionCollection.Count;i++)
			{
				Session tSession = (Session)SessionCollection[i];
				if (tSession.SessionID == lSessionID)
				{
					return true;
				}
			}
			return false;
		}
	}
	#endregion
}
